import unittest
from grammarcorrector import GrammarCorrector

class TestGrammarCorrector(unittest.TestCase):
    def setUp(self):
        self.corrector = GrammarCorrector()

    def test_correction(self):
        input_text = "This are bad grammar sentence."
        expected_output = "This is a bad grammar sentence."
        self.assertEqual(self.corrector.correct(input_text), expected_output)

if __name__ == "__main__":
    unittest.main()
