from setuptools import setup, find_packages

setup(
    name="grammarcorrector",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "replicate>=1.0.4",
    ],
    author="D.",
    author_email="hello@world.com",
    description="A Python package for grammar correction using a remote model on Replicate.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/aaurelions/grammarcorrector",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
